use all4art_authservice_domain::{token::Token, public_key::{self, PublicKey}};

pub struct LoginQueryResult { 
    _token: Token,
}

impl LoginQueryResult { 
    pub fn new(token: Token) -> Self { 
       LoginQueryResult {_token: token}
    }

    pub fn token(&self) -> &Token { 
        &self._token
    }
}
